#!/usr/bin/env python3
# coding=utf-8
#
# Copyright (C) 2016 Bas van den Broek
#

from __future__ import (absolute_import, division,
                        print_function, unicode_literals)

import logging
import sys

logger = logging.getLogger(__name__)


def main():
    pass


if __name__ == '__main__':
    sys.exit(main())



#!/usr/bin/env python3
# coding=utf-8
import unittest

from flask import Flask

from flask_arangodb.arangodb import ArangoDB


class FlaskRequestTests(unittest.TestCase):
    def setUp(self):
        self.app = Flask('test')
        self.context = self.app.test_request_context('/')
        self.context.push()

    def tearDown(self):
        self.context.pop()


class FlaskArangoDBConfigTests(FlaskRequestTests):
    def setUp(self):
        super(FlaskArangoDBConfigTests, self).setUp()
        self.app.config['ARANGO_SETTINGS'] = {'host': 'localhost', 'port': 8529}
        self.app.config['ARANGO_DB'] = 'flask_arangodb_test'

    def test_direct_initialization(self):
        arango = ArangoDB(self.app)
        self.assertIsNotNone(arango.client)

    def test_init_app(self):
        arango = ArangoDB()
        arango.init_app(self.app)
        self.assertIsNotNone(arango.client)


class FlaskArangoDatabaseTests(FlaskRequestTests):
    def setUp(self):
        super(FlaskArangoDatabaseTests, self).setUp()
        self.app.config['ARANGO_SETTINGS'] = {'host': 'localhost', 'port': 8529}
        self.app.config['ARANGO_DB'] = 'flask_arangodb_test'
        self.arango = ArangoDB()
        self.arango.init_app(self.app)
        if 'flask_arangodb_test' not in self.arango.client.databases():
            self.arango.client.create_database('flask_arangodb_test')

    def test_database_access(self):
        self.assertIsNotNone(self.arango.db.properties())



#!/usr/bin/env python3
# coding=utf-8
import arango
from flask import current_app

try:
    from flask import _app_ctx_stack as stack
except ImportError:
    from flask import _request_ctx_stack as stack


class ArangoDB(object):
    def __init__(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        self.app = app
        app.config.setdefault('ARANGO_SETTINGS', {
            "host": "127.0.0.1",
            "port": 8529,
            "username": "root",
            "password": ""
        })
        app.config.setdefault('ARANGO_DB', "default")

    @property
    def client(self):
        ctx = stack.top
        if ctx is not None:
            if not hasattr(ctx, 'arangoclient'):
                ctx.arangoclient = arango.ArangoClient(**current_app.config['ARANGO_SETTINGS'])
            return ctx.arangoclient

    @property
    def db(self):
        return self.client.db(name=self.app.config['ARANGO_DB'])



# coding=utf-8
from setuptools import setup, find_packages

version = {}
with open('./version.py') as fp:
    exec (fp.read(), version)

with open('./README.rst') as fp:
    readme = fp.read().strip()

setup(
    name='Flask-Arangodb',
    version=version['VERSION'],
    license='MIT',
    url='https://github.com/sebastiancodes/Flask-Arangodb',
    description='Flask extension for ArangoDB using python-arango',
    long_description=readme,
    author='Bas van den Broek',
    author_email='cwasvandenbroek@gmail.com',
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    install_requires=[
        'requests',
        'six',
        'python-arango',
        'flask'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
